#!/bin/sh

# Setup script for miscellaneous configuration files.

# Copyright (C) 2009-2014  Simon Ruderich
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


set -eu

. ../lib.sh


# gdb, GNU debugger.
if installed gdb; then
    link gdb/gdbinit ~/.gdbinit
fi

# ghc(i), Glasgow Haskell Compilation.
if installed ghci; then
    link ghc ~/.ghc
    link ghc/ghci ~/.ghci
fi

# Powerful FTP client.
if installed lftp; then
    link lftp ~/.lftp
fi

# Maxima, a symbolic algebra program.
if installed maxima; then
    link maxima ~/.maxima
fi

if installed psql; then
    generate psql/psqlrc .in simple_cpp \
        HISTFILE_PATH -- "`pwd`/psql/history"
    sed_i 's/^#/--/' psql/psqlrc
    link psql/psqlrc ~/.psqlrc
fi

# MySQL client.
if installed mysql; then
    link mysql/my.cnf ~/.my.cnf
fi

if installed sqlite3; then
    # sqlite3 doesn't support any comments in sqliterc.
    grep -v -E '^#' sqlite/sqliterc.in >sqlite/sqliterc
    link sqlite/sqliterc ~/.sqliterc
fi

# perlcritic to check Perl programs for common problems.
if installed perlcritic; then
    link perl/perlcriticrc ~/.perlcriticrc
fi
