#!/bin/sh

# Setup script for VCS configuration files.

# Copyright (C) 2011-2013  Simon Ruderich
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


set -eu

. ../lib.sh


if installed git; then
    generate gitconfig .in simple_cpp PWD -- "`pwd`"

    # Support for old gits.
    if ! git status >/dev/null 2>&1; then
        echo 'gitconfig: removing push.default = simple'
        grep_i -v '^[[:space:]]default = simple$' gitconfig
    fi
    if ! git status >/dev/null 2>&1; then
        echo 'gitconfig: removing color.function'
        sed_i 's/^[[:space:]]*function = .*//' gitconfig
    fi
    if ! git log --patch >/dev/null 2>&1; then
        echo 'gitconfig: replacing git log --patch with -p'
        sed_i 's/log --patch/log -p/' gitconfig
    fi
    if git stash push -- doesnt-exist 2>&1 \
            | grep 'usage: git stash list' > /dev/null; then
        echo 'gitconfig: replacing "stash push" with "stash save"'
        sed_i 's/stash push/stash save/g' gitconfig
    fi

    # If coloredstderr is used to color stderr then remove the workaround for
    # missing output to stderr.
    if test -n "${LD_PRELOAD:+set}" \
            && printf '%s' "$LD_PRELOAD" | grep libcoloredstderr.so >/dev/null; then
        echo 'gitconfig: removing stderr fix'
        sed_i '/^\t\(fs\|fg\)  =/ s/2>&1//' gitconfig
    fi

    link gitconfig ~/.gitconfig
fi

if installed tig; then
    generate tigrc .in cat
    if tig --version | grep '^tig version 2\.[012]' >/dev/null; then
        echo 'tigrc: removing history options'
        grep_i -v '^set history-size = ' tigrc
    fi
    link tigrc ~/.tigrc
fi

if installed hg; then
    link hgrc ~/.hgrc
fi

if installed cvs; then
    # CVS doesn't support any comments nor empty lines in cvsrc.
    grep -E -v '^#' cvsrc.in | grep -E -v '^$' >cvsrc

    link cvsrc ~/.cvsrc
fi
